about summary refs log tree commit diff
path: root/guix/forge/klaus.scm
diff options
context:
space:
mode:
Diffstat (limited to 'guix/forge/klaus.scm')
-rw-r--r--guix/forge/klaus.scm7
1 files changed, 3 insertions, 4 deletions
diff --git a/guix/forge/klaus.scm b/guix/forge/klaus.scm
index cb5815d..11cdbd5 100644
--- a/guix/forge/klaus.scm
+++ b/guix/forge/klaus.scm
@@ -110,11 +110,10 @@
             (list (nginx-location-configuration
                    (uri "/")
                    (body (list (socket->nginx-proxy-pass socket)
                                ;; Pass in the header fields of the original
                                ;; request.
                                "proxy_pass_request_headers on;"
-                               ;; Let klaus know which domain the request was
-                               ;; received for.
+                               "proxy_set_header X-Forwarded-Proto $scheme;"
                                "proxy_set_header Host $host;")))))))))
 
 (define klaus-service-type
@@ -110,11 +110,10 @@
                    (uri "/")
                    (body (list (socket->nginx-proxy-pass socket)
-                               ;; Pass in the header fields of the original
-                               ;; request.
+                               ;; Pass in the host, scheme and header fields of
+                               ;; the original request.
                                "proxy_pass_request_headers on;"